==> cscec5b-wzxt-impl-3.0.0-20210323.100246-180-sources.jar: com/ejianc/business/wzxt/controller/ExitApplyDetailController.java <==
package com.ejianc.business.wzxt.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ExitApplyDetailEntity;
import com.ejianc.business.wzxt.service.IExitApplyDetailService;
import com.ejianc.business.wzxt.vo.ExitApplyDetailVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 退场申请单明细
 *
 * @author generator
 */
@Controller
@RequestMapping("exitApplyDetail")
public class ExitApplyDetailController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IExitApplyDetailService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ExitApplyDetailVO> saveOrUpdate(@RequestBody ExitApplyDetailVO saveorUpdateVO) {
        ExitApplyDetailEntity entity = BeanMapper.map(saveorUpdateVO, ExitApplyDetailEntity.class);
        service.saveOrUpdate(entity, false);
        ExitApplyDetailVO vo = BeanMapper.map(entity, ExitApplyDetailVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ExitApplyDetailVO> queryDetail(Long id) {
        ExitApplyDetailEntity entity = service.selectById(id);
        ExitApplyDetailVO vo = BeanMapper.map(entity, ExitApplyDetailVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ExitApplyDetailVO> vos) {
        service.removeByIds(vos.stream().map(ExitApplyDetailVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ExitApplyDetailVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<ExitApplyDetailEntity> page = service.queryPage(param, false);
        IPage<ExitApplyDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ExitApplyDetailVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    /**
     * 退场明细参照
     *
     * @Param pageNumber: 当前页
     * @Param pageSize: 每页数
     * @Param condition: 查询条件
     * @Param searchText: 模糊查询  pId  退场申请单主键
     * @Return com.ejianc.framework.core.response.CommonResponse<com.baomidou.mybatisplus.core.metadata.IPage < com.ejianc.business.wzxt.vo.OrderDetailVO>>
     * @Author songlx
     * @Date 2021-03-18
     **/
    @RequestMapping(value = "exitApplyDetailRef", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ExitApplyDetailVO>> orderDetailRef(
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        queryParam.getFuzzyFields().add("materialName");
        queryParam.getFuzzyFields().add("materialTypeName");
        queryParam.getFuzzyFields().add("materialCode");
        IPage<ExitApplyDetailVO> pageData = new Page<>();
        if (StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if (null != conditionMap.get("pId")) {
                queryParam.getParams().put("p_id", new Parameter("eq", conditionMap.get("pId")));
                IPage<ExitApplyDetailEntity> page = service.queryPage(queryParam, false);
                pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
                pageData.setRecords(BeanMapper.mapList(page.getRecords(), ExitApplyDetailVO.class));
            }
        }
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


}

==> cscec5b-wzxt-impl-3.0.0-20210325.022027-198-sources.jar: com/ejianc/business/wzxt/controller/ExitApplyDetailController.java <==
package com.ejianc.business.wzxt.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ExitApplyDetailEntity;
import com.ejianc.business.wzxt.service.IExitApplyDetailService;
import com.ejianc.business.wzxt.vo.ExitApplyDetailVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 退场申请单明细
 *
 * @author generator
 */
@Controller
@RequestMapping("exitApplyDetail")
public class ExitApplyDetailController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IExitApplyDetailService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ExitApplyDetailVO> saveOrUpdate(@RequestBody ExitApplyDetailVO saveorUpdateVO) {
        ExitApplyDetailEntity entity = BeanMapper.map(saveorUpdateVO, ExitApplyDetailEntity.class);
        service.saveOrUpdate(entity, false);
        ExitApplyDetailVO vo = BeanMapper.map(entity, ExitApplyDetailVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ExitApplyDetailVO> queryDetail(Long id) {
        ExitApplyDetailEntity entity = service.selectById(id);
        ExitApplyDetailVO vo = BeanMapper.map(entity, ExitApplyDetailVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ExitApplyDetailVO> vos) {
        service.removeByIds(vos.stream().map(ExitApplyDetailVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ExitApplyDetailVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<ExitApplyDetailEntity> page = service.queryPage(param, false);
        IPage<ExitApplyDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ExitApplyDetailVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }


    /**
     * 退场明细参照
     *
     * @Param pageNumber: 当前页
     * @Param pageSize: 每页数
     * @Param condition: 查询条件
     * @Param searchText: 模糊查询  pId  退场申请单主键
     * @Return com.ejianc.framework.core.response.CommonResponse<com.baomidou.mybatisplus.core.metadata.IPage < com.ejianc.business.wzxt.vo.OrderDetailVO>>
     * @Author songlx
     * @Date 2021-03-18
     **/
    @RequestMapping(value = "exitApplyDetailRef", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ExitApplyDetailVO>> orderDetailRef(
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        queryParam.getFuzzyFields().add("materialName");
        queryParam.getFuzzyFields().add("materialTypeName");
        queryParam.getFuzzyFields().add("materialCode");
        IPage<ExitApplyDetailVO> pageData = new Page<>();
        if (StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if (null != conditionMap.get("pId")) {
                queryParam.getParams().put("pId", new Parameter("eq", conditionMap.get("pId")));
                IPage<ExitApplyDetailEntity> page = service.queryPage(queryParam, false);
                pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
                pageData.setRecords(BeanMapper.mapList(page.getRecords(), ExitApplyDetailVO.class));
            }
        }
        return CommonResponse.success("查询列表数据成功！", pageData);
    }


}
